

% 
% m-file which plays with bandpass noise
%  
%
% Author: M. Fitz
% Last modified: 12/01/99
%
fs=22050;
ilength=16384;
time=(0:ilength-1)/fs;
sigma=1.0;
w=sigma*randn(1,ilength);
soundsc(w)
figure(1)
plot(time,w)
title('Noise')
xlabel('time, seconds')
%
% looking at frequency domain
%
wfs=fft(w)/fs;
wf=fftshift(wfs);
%
% Computing output PSD
%
psdw=wf.*conj(wf)/ilength*fs;
psdwdb=10*log10(psdw);
% frequency variable
freq=(-ilength/2:ilength/2-1)/ilength*fs;
figure(3)
plot(freq,psdwdb)
axis([-fs/2 fs/2 -80 -30])
title('Measured Power spectrum input noise')
xlabel('Frequency, Hertz')
% 
%Implementing the bandpass filters
% 
% bw=one-sided bandwidth in Hz
% length=impulse response length in samples
% length must be an even number
bw=1000;
f_c=6500;
length=512;
time2=(0:length)/fs;
half=length/2/fs;
%
% impulse response of an ideal bandpass filter truncated length
% Forcing impulse response to have unit energy
%
hr=2*bw*sinc(2*bw*(time2-half))*2.*cos(2*pi*f_c*(time2-half));
%
% computing frequency domain
%
Hf1=fft(hr,8192);
Hf=fftshift(Hf1)/fs;
freq2=(-4096:4095)/8196*fs;
figure(2)
plot(freq2,10*log10(abs(Hf)))
title('A bandpass filter magnitude transfer function')
xlabel('Frequency, Hz')
%ylabel('|H(f)|, dB')
%
% filtering
%
nc=conv(w,hr)/fs;
nctrun=nc(1:ilength);
soundsc(nc)
%
% Plotting filtered output noise
%
figure(3)
plot(time,nctrun)
title('Filtered noise')
xlabel('Time')
ylabel('N(t)')
%
% Plotting a comparison over a smaller time scale
%
figure(4)
%plot(time(1000:1200),w(1000:1200),'g-',time(1000:1200),nc(1000:1200),'b-')
plot(time(1000:1200),nc(1000:1200),'b-')
%looking at frequency domain
ncfs=fft(nctrun,ilength)/fs;
ncf=fftshift(ncfs);
%
% Computing output PSD
%
psdnc=ncf.*conj(ncf)/ilength*fs;
psdncdb=10*log10(psdnc);
% frequency variable
freq=(-ilength/2:ilength/2-1)/ilength*fs;
figure(5)
plot(freq,psdncdb)
title('Measured power spectrum of bandpass noise"')
xlabel('Frequency, Hertz')
%ylabel('G_m(f), dB')
axis([-fs/2 fs/2 -100 -30])
% 
% Implementing a quadrature demodulator
%
deltaf=0;
ntildei=sqrt(2).*cos(2*pi*(f_c-deltaf)*time).*nctrun;
ntildeq=-sqrt(2).*sin(2*pi*(f_c-deltaf)*time).*nctrun;
% 
%Implementing the lowpass filters
% 
% bw=one-sided bandwidth in Hz
% length=impulse response length in samples
% length must be an even number
bwlp=4000;
length=512;
time2=(0:length)/fs;
half=length/2/fs;
%
% impulse response of an ideal bandpass filter truncated length
%
ht=2*bwlp*sinc(2*bwlp*(time2-half));
%
% filtering
%
ni=conv(ht,ntildei)/fs;
nq=conv(ht,ntildeq)/fs;
%
% Truncating to a length ilength
%
nz=ni(1:ilength)+j*nq(1:ilength);
figure(6)
h=plot(time(1000:1200),ni(1000:1200),'k',time(1000:1200), nq(1000:1200),'b',time(1000:1200), nc(1000-257:1200-257),'r:');
set(h,'linewidth', 2.0)
%looking at frequency domain
nzfs=fft(nz,ilength)/fs;
nzf=fftshift(nzfs);
%
% Computing output PSD
%
psdnz=nzf.*conj(nzf)/ilength*fs;
psdnzdb=10*log10(psdnz);
% frequency variable
freq=(-ilength/2:ilength/2-1)/ilength*fs;
figure(7)
plot(freq,psdnzdb)
title('Measured power spectrum of the noise complex envelope')
xlabel('Frequency, Hertz')
%ylabel('G_n(f), dB')
axis([-5000 5000 -100 -30])
