%  singlebit_ex1.m
%  A Matlab program to play with single bit waveforms and demodulation
%  The example signals is a sine wave pulse and a baseband pulse
%
%  Author: M. Fitz
%  Last revision: 12/31/99
%
%
%  fs=sample rate
%  numsamp=number of samples
% 
%close all
clear all 
fs=22050;
numsamp=22050/50;
% 
% time is the vector of the sample times
%
t_p=100;
time=(0:numsamp-1)/fs;
%
% Generating a cosine pulse
% fm=cosine frequency
% 
fm=441;
x0=sin(2*pi*fm*time);
x0(1:100)=zeros(1,100);
x0(201:441)=zeros(1,441-200);
x1=ones(1,441);
x1(1:100)=zeros(1,100);
x1(202:441)=zeros(1,441-201);
figure(1)
h=plot(220.5*time-1,x0,220.5*time-1,x1)
set(h,'linewidth', 2.0);
axis([-0.1 1.1 -1.2 1.2])
xlabel('Time, t/T_p','FontSize', 16)
ylabel('x_i(t)','FontSize', 16)
legend('x_0(t)','x_1(t)',3)
%%%%%%%%%%%
% plotting 
%%%%%%%%%%%
figure(2)
subplot(2,2,1), h=plot(220.5*time,x0)
set(h,'linewidth', 2.0);
axis([0 4 -1.2 1.2])
xlabel('Time, t/T_p','FontSize', 14)
ylabel('x_0(t)','FontSize', 14)
subplot(2,2,3), h=plot(220.5*time,x1)
set(h,'linewidth', 2.0);
axis([0 4 -1.2 1.2])
xlabel('Time, t/T_p','FontSize', 14)
ylabel('x_i(t)','FontSize', 14)
% 
%Implementing the lowpass filters
% 
% bw=one-sided bandwidth in Hz
% length=impulse response length in samples
% length must be an even number
bw=220.5*4;
ng=2*bw/fs*1.2
length=6*t_p;
time2=(0:length)/fs;
half=length/2/fs;
%
% impulse response of an ideal bandpass filter truncated length
%
ht=2*bw*sinc(2*bw*(time2-half));
%
% filtering
%
ebn0=10;
sigma=sqrt((100+50)/4/ebn0);
w=sigma*randn(1,numsamp);
m0=conv(x0,ht)/fs;
m1=conv(x1,ht)/fs;
n_i=conv(w,ht)/fs;
subplot(2,2,2), h=plot(220.5*time,m0(length/2+1:length/2+numsamp),[220.5*time(187) 220.5*time(187)],[-1.2 1.2], 'r-')
set(h,'linewidth', 2.0);
axis([0 4 -1.2 1.2])
xlabel('Time, t/T_p','FontSize', 14)
ylabel('m_0(t)','FontSize', 14)
subplot(2,2,4), h=plot(220.5*time,m1(length/2+1:length/2+numsamp),[220.5*time(187) 220.5*time(187)],[-1.2 1.2], 'r-')
set(h,'linewidth', 2.0);
axis([0 4 -1.2 1.2])
xlabel('Time, t/T_p','FontSize', 14)
ylabel('m_1(t)','FontSize', 14)
v0=m0(length/2+1:length/2+numsamp)+n_i(length/2+1:length/2+numsamp);
m0sub=m0(length/2+187);
v1=m1(length/2+1:length/2+numsamp)+n_i(length/2+1:length/2+numsamp);
m1sub=m1(length/2+187);
% subplot(2,3,3), h=plot(time,v0,[time(194) time(194)],[-1.2 1.2], 'r-')
% set(h,'linewidth', 2.0);
% axis([0 numsamp/fs -1.2 1.2])
% subplot(2,3,6), h=plot(time,v1,[time(194) time(194)],[-1.2 1.2], 'r-')
% set(h,'linewidth', 2.0);
% axis([0 numsamp/fs -1.2 1.2])
pause
%%
% Looking at the matched filter
%
figure(3)
subplot(2,2,1), h=plot(time/t_p*fs,x0)
set(h,'linewidth', 2.0);
axis([0 4 -1.2 1.2])
xlabel('Time, t/T_p','FontSize', 14)
ylabel('x_0(t)','FontSize', 14)
%title('Average correlation function of the input noise')
%xlabel('time, seconds')
%axis([-half half -1.2 1.2])
subplot(2,2,3), h=plot(time/t_p*fs,x1)
set(h,'linewidth', 2.0);
axis([0 4 -1.2 1.2])
xlabel('Time, t/T_p','FontSize', 14)
ylabel('x_1(t)','FontSize', 14)
%
% Matched filters
% 
lengtho=101;
hopt0=fliplr(x0(101:201));
hopt1=fliplr(x1(101:201));
hopttot=hopt1-hopt0;
m0=conv(x0,hopttot)/t_p;
m0opt=m0(201);
m1=conv(x1,hopttot)/t_p;
m1opt=m1(201);
n_opt=conv(w,hopttot)/t_p;
subplot(2,2,2), h=plot(time/t_p*fs,m0(lengtho:lengtho+numsamp-1),[time(202-lengtho)/t_p*fs time(202-lengtho)/t_p*fs],[-1.2 1.2], 'r-')
set(h,'linewidth', 2.0);
axis([0 4 -1.2 1.2])
xlabel('Time, t/T_p','FontSize', 14)
ylabel('m_0(t)/T_p','FontSize', 14)
subplot(2,2,4), h=plot(time/t_p*fs,m1(lengtho:lengtho+numsamp-1),[time(202-lengtho)/t_p*fs time(202-lengtho)/t_p*fs],[-1.2 1.2], 'r-')
set(h,'linewidth', 2.0);
axis([0 4 -1.2 1.2])
xlabel('Time, t/T_p','FontSize', 14)
ylabel('m_1(t)/T_p','FontSize', 14)
% v0=m0(lengtho:lengtho+numsamp-1)+n_opt(lengtho:lengtho+numsamp-1);
% v1=m1(lengtho:lengtho+numsamp-1)+n_opt(lengtho:lengtho+numsamp-1);
% subplot(2,3,3), h=plot(time/t_p*fs,v0,[time(200-lengtho)/t_p*fs time(200-lengtho)/t_p*fs],[-1.2 1.2], 'r-')
% set(h,'linewidth', 2.0);
% axis([0 4 -1.2 1.2])
% subplot(2,3,6), h=plot(time/t_p*fs,v1,[time(200-lengtho)/t_p*fs time(200-lengtho)/t_p*fs],[-1.2 1.2], 'r-')
% set(h,'linewidth', 2.0);
% axis([0 4 -1.2 1.2])
%
% Plotting signal and matched filter
%
lengtho=105;
hopt0=fliplr(x0(99:203));
hopt1=fliplr(x1(99:203));
hopttot=hopt1-hopt0;
figure(4)
% plot(time(99:203)/t_p*fs-1,x1(99:203)-x0(99:203))
% xlabel('Time, t/T_p','FontSize', 14)
% ylabel('b_{10}(t)','FontSize', 14)
plot(time(99:203)/t_p*fs-1,hopttot)
xlabel('Time, t/T_p','FontSize', 14)
ylabel('h(t)','FontSize', 14)
pause
v0sub=[];
v1sub=[];
v0opt=[];
v1opt=[];
xsub=linspace(-3.5,3.5,200);
xopt=linspace(-2,1.5,200);
for ii=1:4000
	w=sigma*randn(1,numsamp);
	n_sub=conv(w,ht)/fs;
	n_opt=conv(w,hopttot)/t_p;
	v0sub=[v0sub m0sub+n_sub(length/2+187)];
	v1sub=[v1sub m1sub+n_sub(length/2+187)];
	v0opt=[v0opt m0opt+n_opt(226)];
	v1opt=[v1opt m1opt+n_opt(226)];
% 	if mod(ii,100)==0
% 		figure(4)
% 		subplot(2,2,1), hist(v0sub,xsub)
% 		subplot(2,2,3), hist(v1sub,xsub)
% 		subplot(2,2,2), hist(v0opt,xopt)
% 		subplot(2,2,4), hist(v1opt,xopt)
% 		%pause(1)
% 	end
end	
figure(5)
subplot(2,2,2), hist(v0sub,xsub)
subplot(2,2,4), hist(v1sub,xsub)
m0=conv(x0,ht)/fs;
m1=conv(x1,ht)/fs;
n_i=conv(w,ht)/fs;
v0=m0(length/2+1:length/2+numsamp)+n_i(length/2+1:length/2+numsamp);
v1=m1(length/2+1:length/2+numsamp)+n_i(length/2+1:length/2+numsamp);
subplot(2,2,1), h=plot(time/t_p*fs,v0,[time(187)/t_p*fs time(187)/t_p*fs],[-2 2], 'r-')
set(h,'linewidth', 2.0);
axis([0 4 -2 2])
xlabel('Time, t/T_p','FontSize', 14)
ylabel('v_0(t)','FontSize', 14)
subplot(2,2,3), h=plot(time/t_p*fs,v1,[time(187)/t_p*fs time(187)/t_p*fs],[-2 2], 'r-')
set(h,'linewidth', 2.0);
axis([0 4 -2 2])
xlabel('Time, t/T_p','FontSize', 14)
ylabel('v_1(t)','FontSize', 14)
figure(6)
subplot(2,2,2), hist(v0opt,xsub)
subplot(2,2,4), hist(v1opt,xsub)
m0=conv(x0,hopttot)/t_p;
m1=conv(x1,hopttot)/t_p;
n_opt=conv(w,hopttot)/t_p;
v0=m0(lengtho:lengtho+numsamp-1)+n_opt(lengtho:lengtho+numsamp-1);
v1=m1(lengtho:lengtho+numsamp-1)+n_opt(lengtho:lengtho+numsamp-1);
subplot(2,2,1), h=plot(time/t_p*fs,v0,[time(203-lengtho)/t_p*fs time(203-lengtho)/t_p*fs],[-1.2 1.2], 'r-')
set(h,'linewidth', 2.0);
axis([0 4 -1.2 1.2])
xlabel('Time, t/T_p','FontSize', 14)
ylabel('v_0(t)','FontSize', 14)
subplot(2,2,3), h=plot(time/t_p*fs,v1,[time(203-lengtho)/t_p*fs time(203-lengtho)/t_p*fs],[-1.2 1.2], 'r-')
set(h,'linewidth', 2.0);
axis([0 4 -1.2 1.2])
xlabel('Time, t/T_p','FontSize', 14)
ylabel('v_1(t)','FontSize', 14)
