% 
% Generating the time waveform of OFDM
% and looking at the matched filter output
% Author: M. Fitz
% Last modified: 9/24/01
% 
close all
clear all
numpts=2048;
K_b=4;
f_d=0.5;
T_p=1;
time=linspace(0,T_p, numpts+1);
x_z=zeros(1,numpts+1);
for kk=1:K_b
    d_z(kk)=sign(rand(1)-0.5);
	tonekk=d_z(kk)*exp(j*2*pi*f_d*(2*kk-K_b-1)*time);
	x_z=x_z+tonekk;
end
d_z
figure(1)
plot(x_z)
hs=subplot(1,1,1);
set(hs,'Fontsize',14);
xlabel('x_I(t)','Fontsize',16)
ylabel('x_Q(t)','Fontsize',16)
x_a=abs(x_z);
figure(2)
plot(time, x_a)
hs=subplot(1,1,1);
set(hs,'Fontsize',14);
xlabel('Normalized time, t/T_p','Fontsize',16)
ylabel('x_A(t)','Fontsize',16)
%
%  Looking at subcarrier matched filters
%
carrier_num=[1 2 3 4];
for ii = 1:1:length(carrier_num)
    delta_f=f_d*(2*carrier_num(ii)-K_b-1);
	temp = exp(j*2*pi*delta_f*time);
    %m_f(ii,:) = fliplr(conj(temp));
    m_f(ii,:)= temp*exp(-j*2*pi*delta_f);
    mf_output(ii,:) = conv(x_z,m_f(ii,:))/numpts;
end
mf_sampled=mf_output(:,numpts);
if length(carrier_num) == 1 
    figure
    plot(mf_sampled(1),'ro')
    title(['Carrier number = ',num2str(carrier_num(1))])
	xlabel('Q_I(k)','Fontsize',12)
    ylabel('Q_Q(k)','Fontsize',12)
	axis([-1.5 1.5 -1.5 1.5])
elseif length(carrier_num) == 2
    figure
    subplot(211)
    plot(mf_sampled(1),'ro')
    title(['Carrier number = ',num2str(carrier_num(1))])
	xlabel('Q_I(k)','Fontsize',12)
    ylabel('Q_Q(k)','Fontsize',12)
	axis([-1.5 1.5 -1.5 1.5])
    subplot(212)
    plot(mf_sampled(2),'.')
    title(['Carrier number = ',num2str(carrier_num(2))])
	xlabel('Q_I(k)','Fontsize',12)
    ylabel('Q_Q(k)','Fontsize',12)
	axis([-1.5 1.5 -1.5 1.5])
elseif length(carrier_num) == 3
    figure
    subplot(221)
    plot(mf_sampled(1),'ro')
    title(['Carrier number = ',num2str(carrier_num(1))])
	xlabel('Q_I(k)','Fontsize',12)
    ylabel('Q_Q(k)','Fontsize',12)
	axis([-1.5 1.5 -1.5 1.5])
    subplot(222)
    plot(mf_sampled(2),'ro')
    title(['Carrier number = ',num2str(carrier_num(2))])
	xlabel('Q_I(k)','Fontsize',12)
    ylabel('Q_Q(k)','Fontsize',12)
	axis([-1.5 1.5 -1.5 1.5])
    subplot(212)
    plot(mf_sampled(3),'.')
    title(['Carrier number = ',num2str(carrier_num(3))])
	xlabel('Q_I(k)','Fontsize',12)
    ylabel('Q_Q(k)','Fontsize',12)
	axis([-1.5 1.5 -1.5 1.5])
elseif length(carrier_num) == 4
    figure
    subplot(221)
    plot(mf_sampled(1),'ro')
    title(['Carrier number = ',num2str(carrier_num(1))])
	xlabel('Q_I(k)','Fontsize',12)
    ylabel('Q_Q(k)','Fontsize',12)
	axis([-1.5 1.5 -1.5 1.5])
    subplot(222)
    plot(mf_sampled(2),'ro')
    title(['Carrier number = ',num2str(carrier_num(2))])
	xlabel('Q_I(k)','Fontsize',12)
    ylabel('Q_Q(k)','Fontsize',12)
	axis([-1.5 1.5 -1.5 1.5])
    subplot(223)
    plot(mf_sampled(3),'ro')
    title(['Carrier number = ',num2str(carrier_num(3))])
	xlabel('Q_I(k)','Fontsize',12)
    ylabel('Q_Q(k)','Fontsize',12)
	axis([-1.5 1.5 -1.5 1.5])
    subplot(224)
    plot(mf_sampled(4),'ro')
    title(['Carrier number = ',num2str(carrier_num(4))])
	xlabel('Q_I(k)','Fontsize',12)
    ylabel('Q_Q(k)','Fontsize',12)
	axis([-1.5 1.5 -1.5 1.5])
end
