% sigsex2.m
% m-file for playing around with a voice signal
% Examples for signals and systems review 
% Author: M. Fitz
% Last modified: 12/31/99
%
close all
load voice
% voice.mat is a file containing variables z and fs
% z is a computer generated voice saying "bingo"
% fs=sampling rate 22050Hz
% z has 16384 samples
[ilength jlength]=size(z);
% time variable is the sample number times the sample period
time=(0:ilength-1)/fs;
% looking at time waveform
figure(1)  % This is Fig. 2.1
plot(time,z) 
xlabel('time, seconds','Fontsize',16)
ylabel('x(t)','Fontsize',16)
sound(z,fs)
% computing the energy of the time waveform
% Using Reimann sum approximation to integral
zdum=z.*conj(z);
eztbb=sum(zdum)/fs;
% computing power in the voice signal
pzt=eztbb/ilength*fs
%looking a frequency domain
zfs=fft(z);
%
% Does Rayleigh energy thoerem work?
%
ezfbb=sum(zfs.*conj(zfs))/ilength/fs; 
zf=fftshift(zfs);
% frequency variable
freq=(-ilength/2:ilength/2-1)/ilength*fs;
%
% Calculating PSD in dB
%
psdz=zf.*conj(zf)/ilength/fs;
psdzdb=10*log10(psdz);
% 
% Power in frequency domain
%
pzf=sum(psdz)*fs/ilength
figure(2)
plot(freq,psdzdb)   % Fig. 2.3 b)
axis([-5000 5000 -80 -30])
%title('Power spectrum of the filtered voice saying "Bingo"')
xlabel('Frequency, f, Hertz','Fontsize',16)
ylabel('G_x(f), dB','Fontsize',16)
%
% specifying the impulse response of a lowpass filter
%
% bw=one-sided bandwidth in Hz
% length=impulse response length in samples
% length must be an even number and less than 4096
bw=2500;
length=2048;
time2=(0:length)/fs;
half=length/2/fs;
%
% impulse response of an ideal bandpass filter truncated length
%
ht=2*bw*sinc(2*bw*(time2-half));
figure(3)
plot(time2,ht)
%title('Low pass filter impulse response for W=2.5KHz')
xlabel('time, seconds','Fontsize',16)
ylabel('h(t)','Fontsize',16)
axis([0.036 0.056 -2000 5000])
%ylabel('h(t)')
%
% computing frequency domain
%
Hf1=fft(ht,8192);
Hf=fftshift(Hf1)/fs;
freq2=(-4096:4095)/8192*fs;
figure(4)
plot(freq2,10*log10(abs(Hf)))
%title('A lowpass filter magnitude transfer function')
xlabel('Frequency, Hz','Fontsize',16)
ylabel('H(f)','Fontsize',16)
%ylabel('|H(f)|, dB')
axis([-5000 5000 -60 10])
% 
% Filtering the voice signal
%
yout=conv(ht,z)/fs;
time3=(0:length+ilength-1)/fs;
%
%  Looking at the output time signal
%
figure(5)
plot(time3',yout)
soundsc(z,fs)
title('Filtered voice saying "Bingo"')
xlabel('time, seconds')
%ylabel('m(t)')
soundsc(yout,fs)
%looking at frequency domain
youtfs=fft(yout,ilength)/fs;
youtf=fftshift(youtfs);
%
% Computing output PSD
%
psdyout=youtf.*conj(youtf)/ilength*fs;
psdyoutdb=10*log10(psdyout);
% frequency variable
freq=(-ilength/2:ilength/2-1)/ilength*fs;
figure(6)
plot(freq,psdyoutdb)
axis([-5000 5000 -80 -30])
xlabel('Frequency, f, Hz','Fontsize',16,'Position', [-8.5034 -82 0])
ylabel('G_y(f)','Fontsize',16, 'Position', [-5600 -55 0])
m=yout;
save message m fs
