% bpex3.m
% m-file looks at bandpass signals
%  
%
% Author: M. Fitz
% Last modified: 1/2/00
%
load message
% message.mat is a file containing variables m and fs
% m is a filtered computer generated voice saying "bingo"
% m was generated in Chap1Ex2.m
% fs=sampling rate 22050Hz
% Truncating mess to a length of 16384
mess=m(1:16384);
[ilength jlength]=size(mess);
% time variable is the sample number times the sample period
time=(0:ilength-1)/fs;
% looking at time waveform
%
% Looking at a bandpass signal with 
% 1) the voice signal in the in-phase channel
% 2) a sinusoid in the quadrature channel
%
xi=transpose(mess);
%xi=cos(2*pi*2000*time);
xq=cos(2*pi*500*time);
figure(1)
plot(time,xq,time,xi,'r')
title('Baseband signals')
xlabel('time, seconds')
%ylabel('x_#(t)')
%
% Outputting sounds
%
soundsc(xi,fs)
soundsc(xq,fs)
% 
% Computing complex envelope
%
xz=xi+j*xq;
%
% Looking at frequency domain
%
xzfs=fft(xz)/fs;
xzf=fftshift(xzfs);
psdxz=xzf.*conj(xzf)/ilength*fs;
% frequency variable
freq=(-ilength/2:ilength/2-1)/ilength*fs;
figure(2)
plot(freq,10*log10(psdxz))
axis([-5000 5000 -70 0])
%title('Power spectrum of the complex envelope')
xlabel('Frequency, f, Hertz','Fontsize',16,'position',[0 -74 0])
ylabel('G_{y_z}(f)','Fontsize',16)
% 
% Implementing a quadrature modulator
% f_c=carrier frequency
%
f_c=7000;
xtildei=sqrt(2)*xi.*cos(2*pi*f_c*time);
xtildeq=sqrt(2)*xq.*sin(2*pi*f_c*time);
xc=xtildei-xtildeq;
soundsc(xc)
% 
% Looking at bandpass time signal
%
figure(3)
plot(time,xc)
%
% Zoom of bandpass time signal
%
figure(4)
plot(time(3300:3500), xc(3300:3500),'r--',time(3300:3500), xi(3300:3500),time(3300:3500), xq(3300:3500))
h=plot(time(3300:3500), xc(3300:3500),'r--',time(3300:3500), xi(3300:3500),time(3300:3500), xq(3300:3500));
set(h,'linewidth', 2.0)
%
% Looking at frequency domain for bandpass
%
xcfs=fft(xc)/fs;
xcf=fftshift(xcfs);
% frequency variable
freq=(-ilength/2:ilength/2-1)/ilength*fs;
figure(5)
psdxc=xcf.*conj(xcf)/ilength*fs;
plot(freq,10*log10(psdxc))
axis([-11000 11000 -70 0])
xlabel('Frequency, f, Hertz','Fontsize',16,'position',[0 -74 0])
ylabel('G_{y_c}(f)','Fontsize',16)
% 
% Implementing a quadrature demodulator
%
deltaf=0;
ytildei=sqrt(2).*cos(2*pi*(f_c-deltaf)*time).*xc;
ytildeq=-sqrt(2).*sin(2*pi*(f_c-deltaf)*time).*xc;
% 
%Implementing the lowpass filters
% 
% bw=one-sided bandwidth in Hz
% length=impulse response length in samples
% length must be an even number
bw=4000;
length=512;
time2=(0:length)/fs;
half=length/2/fs;
%
% impulse response of an ideal bandpass filter truncated length
%
ht=2*bw*sinc(2*bw*(time2-half));
%
% filtering
%
yi=conv(ht,ytildei)/fs;
yq=conv(ht,ytildeq)/fs;
%
% Truncating to a length 16384 and looking at time domain output
%
yz=yi(1:16384)+j*yq(1:16384);
figure(6)
plot(time, yq(1:16384), time,yi(1:16384),'r')
%
% Looking at frequency domain
%
yzfs=fft(yz)/fs;
yzf=fftshift(yzfs);
psdyz=yzf.*conj(yzf)/ilength*fs;
% frequency variable
freq=(-ilength/2:ilength/2-1)/ilength*fs;
figure(7)
plot(freq,10*log10(psdyz))
axis([-5000 5000 -70 00])
soundsc(yi,fs)
soundsc(yq,fs)
