

% 
% m-file for generating a double sideband amplitude modulated signal
%  
%
% Author: M. Fitz
% Last modified: 1/9/00
%
load message
% message.mat is a file containing variables m and fs
% m is a filtered computer generated voice saying "bingo"
% m was generated in Chap1Ex2.m
% fs=sampling rate 22050Hz
% Truncating mess to a length of 16384
mess=m(1:16384);
[ilength jlength]=size(mess);
% time variable is the sample number times the sample period
time=(0:16383)/fs;
% looking at time waveform
figure(1)
plot(time,mess)
title('Computer generated voice saying "Bingo"')
xlabel('time, seconds')
ylabel('m(t)')
soundsc(mess,fs)
%
% Looking at the frequency domain for the message signal
%
mfs=fft(mess)/fs;
mf=fftshift(mfs);
psdm=mf.*conj(mf)/ilength*fs;
% frequency variable
freq=(-ilength/2:ilength/2-1)/ilength*fs;
figure(2)
plot(freq,10*log10(psdm))
axis([-5000 5000 -90 -30])
title('Power spectrum of the filtered voice saying "Bingo"')
xlabel('Frequency, Hertz')
%
%  Double side band - Amplitude modulation
%  Note:  W=3KHz (approximately)
%         f_c=4KHz
%         A_c=1/sqrt(2)  
%  Note A_c is chosen so that the carrier modulated signal has the same
%  peak amplitude as the message signal so Fig. 4 will look good.
f_c1=9000;
f_c2=5000;
A_c=1/sqrt(2);
%
%  Generating the complex envelope
%
xz=A_c*mess;
%
%  Generating the bandpass signal
%
xc=sqrt(2)*real(xz.*transpose(exp(j*2*pi*f_c1*time)));
xc=xc+sqrt(2)*real(xz.*transpose(exp(j*2*pi*f_c2*time)));
figure(3)
%
%  Plotting the time waveform for the bandpass signal
%
plot(time,xc)
title('Double side band amplitude modulation')
xlabel('time, seconds')
%ylabel('x_c(t)')
% 
%  Zooming in on a smaller time scale to get a better idea of DSB-AM
%
figure(4)
plot(time(1600:2000),mess(1600:2000),time(1600:2000),xc(1600:2000))
h=plot(time(1600:2000),mess(1600:2000),time(1600:2000),xc(1600:2000));
set(h,'linewidth', 2.0)
title('Message signal and the modulated signal')
xlabel('time, seconds')
%ylabel('x_c(t)')
%
% Looking at the output DSB-AM signal in the frequency domain
%
xcfs=fft(xc)/fs;
xcf=fftshift(xcfs);
psdxc=xcf.*conj(xcf)/ilength*fs;
figure(5)
plot(freq,10*log10(psdxc))
axis([-fs/2 fs/2 -90 -30])
title('Power spectrum of the DSB-AM signal')
xlabel('Frequency, Hertz')
save dsbam mess xc f_c fs
