% 
% m-file for generating a phase and a frequency modulated signal
% sinusoidal message signal
%  
%
% Author: M. Fitz
% Last modified: 9/16/00
%
% time variable is the sample number times the sample period
fs=22050;
time=(0:16383)/fs;
%
% Generating a sinusoidal signal 
% f_m=message frequency
% A_m=message amplitude
%
f_m=300;
A_m=1;
mess=A_m*transpose(cos(2*pi*f_m*time));
[ilength jlength]=size(mess);
%
% looking at time waveform
%
figure(1)
plot(time,mess)
title('Message signal')
xlabel('time, seconds')
ylabel('m(t)')
soundsc(mess,fs)
%
%  Computing the important message parameters for 
%  for angle modulation
%
dmdt=diff(mess)*fs;
maxder=max(abs(dmdt));
maxm=max(abs(mess));
%
% Integral of the message signal
% Trapezoidal integration
%
intmess=(cumsum(mess)-mess(1)/2)/fs;
%
% Looking at the frequency domain for the message signal
%
mfs=fft(mess)/fs;
mf=fftshift(mfs);
psdmf=mf.*conj(mf)*fs/ilength;
% frequency variable
freq=(-ilength/2:ilength/2-1)/ilength*fs;
figure(2)
plot(freq,10*log10(psdmf))
axis([-5000 5000 -50 10])
title('Power spectrum of sinusoidal message')
xlabel('Frequency, Hertz')
%
%  phase and frequency modulation
%  Note:  f_c=2.3KHz
%         A_c=1/sqrt(2)  
%         k_p=1
%         k_f=2pi*200
f_c=2300;
A_c=1/sqrt(2);
%
%  Set parameters to give beta=3
%  For both FM and PM
%
k_p=2.0;
k_f=2*pi*300;
%
%  Generating the complex envelope
%
% Phase modulation
%
xz=A_c*exp(j*k_p*mess);
%
% Frequency modulation
%
%xz=A_c*exp(j*k_f*intmess);
%
% Playing around with Bessel functions
%
%xz=besselj(0,3)+j*2*besselj(1,3)*sin(2*pi*200*time)+2*besselj(2,3)*cos(2*pi*400*time);
%  Plotting a vector diagram of the modulated complex envelope
%
figure(3)
plot(xz)
axis([-1 1 -1 1])
title('Vector Diagram for Angle Modulation')
xlabel('x_I(t)')
ylabel('x_Q(t)')
%
%
%  Displaying the peak frequency deviation
%  (PM)
'phase modulation'
'[peak frequency deviation, beta]'
[k_p/2/pi*maxder k_p*A_m]
%
%  Displaying the peak frequency deviation
%  (FM)
% 'frequency modulation'
% '[peak frequency deviation, beta]'
% [k_f*maxm/2/pi k_f*maxm/2/pi/f_m]
%
% Looking at frequency domain
%
xzfs=fft(xz)/fs;
xzf=fftshift(xzfs);
%
% Computing Carson's bandwidth
%
psdxzf=fs/ilength*abs(xzf(ilength/2+1:ilength)).^2;
totpow=2*sum(psdxzf);
cumpow=2*cumsum(psdxzf)/totpow;
figure(4)
% frequency variable
freq=(-ilength/2:ilength/2-1)/ilength*fs;
plot(freq(ilength/2+1:ilength),cumpow);
axis([0 2000 0.9 1])
title('Cumulative power as a function of frequency')
xlabel('Frequency,f,Hz')
ylabel('Cumulative power')
%
%
%
% Filtering to limit the spectral content before upconverting
% 
% 
%Implementing the lowpass filters
% 
% bw=one-sided bandwidth in Hz
% length=impulse response length in samples
% length must be an even number
bw=2000;
length=512;
time2=(0:length)/fs;
half=length/2/fs;
%
% impulse response of an ideal bandpass filter truncated length
%
ht=2*bw*sinc(2*bw*(time2-half));
%
% filtering
%
xz1=conv(ht,xz)/fs;
xzout=xz1(1:16384);
%
% Looking at frequency domain
%
xzfs1=fft(xzout)/fs;
xzf1=fftshift(xzfs1);
psdxz1=xzf1.*conj(xzf1)*fs/ilength;
figure(5)
plot(freq,10*log10(psdxz1))
axis([-5000 5000 -60 0])
title('Power spectrum of the complex envelope')
xlabel('Frequency, Hertz')
%
%  Generating the bandpass signal
%
xc=real(xzout).*cos(2*pi*f_c*time')-imag(xzout).*sin(2*pi*f_c*time');
figure(6)
%
%  Plotting the time waveform for the bandpass signal
%
plot(time,xc)
title('Angle modulation')
xlabel('time, seconds')
%ylabel('x_c(t)')
% 
%  Zooming in on a smaller time scale to get a better idea of angle modulation
%
%  Note the message signal must be delayed  since the xz is passed through a 
%  filter
%   
figure(7)
plot(time(3600:3800),mess(3600-length/2:3800-length/2),time(3600:3800),xc(3600:3800))
title('Message signal and the modulated signal')
xlabel('time, seconds')
%ylabel('x_c(t)')
%
% Looking at the output angle modulated signal in the frequency domain
%
xcfs=fft(xc)/fs;
xcf=fftshift(xcfs);
psdxc=xcf.*conj(xcf)*fs/ilength;
figure(8)
plot(freq,10*log10(psdxc))
axis([-fs/2 fs/2 -60 00])
title('Power spectrum of the bandpass signal')
xlabel('Frequency, Hertz')
save pm mess xc f_c fs
