% 
% m-file that looks at the sinusoidal message case and the Fourier series 
% representation
%  
%
% Author: M. Fitz
% Last modified: 9/16/00
%
% time variable is the sample number times the sample period
fs=22050;
time=(0:16383)/fs;
%
% Generating a sinusoidal signal 
% f_m=message frequency
% A_m=message amplitude
%
f_m=300;
A_m=1;
mess=A_m*transpose(sin(2*pi*f_m*time));
[ilength jlength]=size(mess);
%
% looking at time waveform
%
figure(1)
plot(time,mess)
title('Message signal')
xlabel('time, seconds')
ylabel('m(t)')
soundsc(mess,fs)
%
%  Computing the important message parameters for 
%  for angle modulation
%
dmdt=diff(mess)*fs;
maxder=max(abs(dmdt));
maxm=max(abs(mess));
%
% Integral of the message signal
% Trapezoidal integration
%
intmess=(cumsum(mess)-mess(1)/2)/fs;
%  phase and frequency modulation
%  Note:  f_c=2.3KHz
%         A_c=1/sqrt(2)  
%         k_p=1
%         k_f=2pi*200
f_c=2300;
A_c=1/sqrt(2);
%
%  Set parameters to give beta=3
%  For both FM and PM
%
beta=3.0;
%
%  Generating the complex envelope
%
% Phase modulation
%
xzid=A_c*exp(j*beta*mess);
%
% frequency variable
%
freq=(-ilength/2:ilength/2-1)/ilength*fs;
for n=0:10
	if(n==0)
  	  xzap=A_c*bessel(n,beta)*ones(size(time))+10^(-14)*(randn(size(time))+j*randn(size(time)));
 	else
	  xzap=xzap+A_c*bessel(n,beta)*exp(j*2*pi*n*f_m*time)+A_c*bessel(-n,beta)*exp(-j*2*pi*n*f_m*time);
	end
%
%  Plotting a vector diagram of the modulated complex envelope
%
	figure(3)
	plot(xzid)
	hold on
	plot(xzap,'g-')
	hold off
	axis([-1 1 -1 1])
	title('Vector Diagram for Angle Modulation')
	xlabel('x_I(t)')
	ylabel('x_Q(t)')
%
% Looking at frequency domain
%
	xzfs=fft(xzid)/fs;
	xzf=fftshift(xzfs);
	psdxzid=xzf.*conj(xzf)*fs/ilength;
	xzfs=fft(xzap)/fs;
	xzf=fftshift(xzfs);
	psdxzap=xzf.*conj(xzf)*fs/ilength;
	figure(5)
	plot(freq,10*log10(psdxzid),freq,10*log10(psdxzap))
	axis([-5000 5000 -60 0])
	title('Power spectrum of the complex envelope')
	xlabel('Frequency, Hertz')
%
%  Generating the bandpass signal
%
	xcid=real(xzid).*cos(2*pi*f_c*time')-imag(xzid).*sin(2*pi*f_c*time');
	xcap=real(xzap).*cos(2*pi*f_c*time)-imag(xzap).*sin(2*pi*f_c*time);
% 
%  Zooming in on a smaller time scale to get a better idea of angle modulation
%
%  Note the message signal must be delayed  since the xz is passed through a 
%  filter
%   
	figure(7)
	plot(time(3600:3800),mess(3600:3800),time(3600:3800),xcid(3600:3800),time(3600:3800),xcap(3600:3800))
	title('Message signal and the modulated signal')
	xlabel('time, seconds')
	pause
end
pause
