% 
% Generating the time waveform of OFDM
% and looking at the matched filter output
% Author: M. Fitz
% Last modified: 9/24/01
% 
close all
clear all
numpts=2048;
K_b=3;
f_d=0.5;
T_p=1;
T_h=0.25;
time=linspace(0,T_p, numpts+1);
timepre=linspace(-T_h,T_p, (T_p+T_h)*numpts+1);
x_z=zeros(1,numpts+1);
x_zpre=zeros(1,(T_p+T_h)*numpts+1);
for kk=1:K_b
    d_z(kk)=sign(rand(1)-0.5);
	tone(kk,:)=d_z(kk)*exp(j*2*pi*f_d*(2*kk-K_b-1)*time);
	tonepre(kk,:)=d_z(kk)*exp(j*2*pi*f_d*(2*kk-K_b-1)*timepre);
	x_z=x_z+tone(kk,:);
	x_zpre=x_zpre+tonepre(kk,:);
end
d_z
%
% Plotting vector diagram
%
figure(1)
plot(x_z)
hs=subplot(1,1,1);
set(hs,'Fontsize',14);
xlabel('x_I(t)','Fontsize',16)
ylabel('x_Q(t)','Fontsize',16)
x_a=abs(x_z);
%
% Plotting amplitude
%
figure(2)
plot(time, x_a)
hs=subplot(1,1,1);
set(hs,'Fontsize',14);
xlabel('Normalized time, t/T_p','Fontsize',16)
ylabel('x_A(t)','Fontsize',16)
%
% Plotting subcarriers and signals without prefix
%
figure(3)
subplot(221)
plot(time,real(tone(1,:)),time,imag(tone(1,:)))
title(['Carrier number = 1'])
xlabel('Normalized Time, t/T_p','Fontsize',12)
ylabel('Signal 1','Fontsize',12)
axis([0 1.0 -1.5 1.5])
subplot(222)
plot(time,real(tone(2,:)),time,imag(tone(2,:)))
xlabel('Normalized Time, t/T_p','Fontsize',12)
ylabel('Signal 2','Fontsize',12)
axis([-0.0 1.0 -1.5 1.5])
subplot(223)
plot(time,real(tone(3,:)),time,imag(tone(3,:)))
xlabel('Normalized Time, t/T_p','Fontsize',12)
ylabel('Signal 3','Fontsize',12)
axis([-0.0 1.0 -1.5 1.5])
subplot(224)
plot(time,real(x_z),time,imag(x_z))
xlabel('Normalized Time, t/T_p','Fontsize',12)
ylabel('x_z(t)','Fontsize',12)
axis([-0.0 1.0 -3 3])
%
%  Plotting signal with cyclic prefix
%
figure(4)
subplot(221)
plot(timepre,real(tonepre(1,:)),timepre,imag(tonepre(1,:)))
title(['Carrier number = 1'])
xlabel('Normalized Time, t/T_p','Fontsize',12)
ylabel('Signal 1','Fontsize',12)
axis([-0.25 1.0 -1.5 1.5])
subplot(222)
plot(timepre,real(tonepre(2,:)),timepre,imag(tonepre(2,:)))
xlabel('Normalized Time, t/T_p','Fontsize',12)
ylabel('Signal 2','Fontsize',12)
axis([-0.25 1.0 -1.5 1.5])
subplot(223)
plot(timepre,real(tonepre(3,:)),timepre,imag(tonepre(3,:)))
xlabel('Normalized Time, t/T_p','Fontsize',12)
ylabel('Signal 3','Fontsize',12)
axis([-0.25 1.0 -1.5 1.5])
subplot(224)
plot(timepre,real(x_zpre),timepre,imag(x_zpre))
xlabel('Normalized Time, t/T_p','Fontsize',12)
ylabel('x_z(t)','Fontsize',12)
axis([-0.25 1.0 -3 3])
