% A progroam to play with stream modulations in ISI channels
% Specialized for two taps
%
close all
clear all
%
% setting the channel
%
K_b=401
g1=0.2862*exp(j*2*pi/3)
gvec1=[1 g1];
glong1=toeplitz([gvec1 zeros(1,K_b-2)]);
g2=0.4999*exp(j*pi/3)
gvec2=[1 g2];
glong2=toeplitz([gvec2 zeros(1,K_b-2)]);
%
%  Plotting the frequency response
%
freq=linspace(-0.5,0.5,201);
Gf1=g1*exp(-j*2*pi*freq)+1+conj(g1)*exp(j*2*pi*freq);
Gf2=g2*exp(-j*2*pi*freq)+1+conj(g2)*exp(j*2*pi*freq);
figure(1)
plot(freq, 10*log10(abs(Gf1)),freq, 10*log10(abs(Gf2)))
xlabel('Normalized Frequency, f')
ylabel('|G(e^{j2\pif})|,dB')
legend('Channel 1','Channel 2')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  Looking at the decorrelator
%
ginvlong1=inv(glong1);
ginvlong2=inv(glong2);
%
% Looking at the zero forcing equalizer impulse response
% Approximated by the middle row of the inverse of G when
% K_b is very large.
%
one_sided_tail=floor(K_b/2);
wzfe1=ginvlong1(one_sided_tail+1,:);
wzfe2=ginvlong2(one_sided_tail+1,:);
%
% Channel 1 frequency response
%
Wzf1=wzfe1*exp(-j*2*pi*linspace(-one_sided_tail,one_sided_tail,K_b)'*freq);
figure(2)
plot(freq, 10*log10(abs(Wzf1)),freq, 10*log10(abs(Gf1)))
xlabel('Normalized Frequency, f')
ylabel('Transfer function ,dB')
legend('ZF Equalizer 1','Channel 1')
%
% Channel 2 frequency response
%
Wzf2=wzfe2*exp(-j*2*pi*linspace(-one_sided_tail,one_sided_tail,K_b)'*freq);
figure(3)
plot(freq, 10*log10(abs(Wzf2)),freq, 10*log10(abs(Gf2)))
xlabel('Normalized Frequency, f')
ylabel('Transfer function ,dB')
legend('ZF Equalizer 2','Channel 2')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  Looking at the MMSE detector
%
e_b_n_0=10;
gmmseinvlong1=inv(glong1+(1/e_b_n_0)*eye(K_b));
gmmseinvlong2=inv(glong2+(1/e_b_n_0)*eye(K_b));
%
% Looking at the MMSE equalizer impulse response
% Approximated by the middle row of the inverse of G when
% K_b is very large.
%
one_sided_tail=floor(K_b/2);
wmmse1=gmmseinvlong1(one_sided_tail+1,:);
wmmse2=gmmseinvlong2(one_sided_tail+1,:);
%
% Channel 1 frequency response
%
Wmmse1=wmmse1*exp(-j*2*pi*linspace(-one_sided_tail,one_sided_tail,K_b)'*freq);
figure(4)
plot(freq, 10*log10(abs(Wmmse1)),freq, 10*log10(abs(Gf1)))
xlabel('Normalized Frequency, f')
ylabel('Transfer function ,dB')
legend('MMSE Equalizer 1','Channel 1')
%
% Channel 2 frequency response
%
Wmmse2=wmmse2*exp(-j*2*pi*linspace(-one_sided_tail,one_sided_tail,K_b)'*freq);
figure(5)
plot(freq, 10*log10(abs(Wmmse2)),freq, 10*log10(abs(Gf2)))
xlabel('Normalized Frequency, f')
ylabel('Transfer function ,dB')
legend('MMSE Equalizer 2','Channel 2')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  Looking at the anti-causaul MMSE equalizer
%
%
% Looking at the anti-causal MMSE equalizer impulse response
% Approximated by the first row of the inverse of G when
% K_b is very large.
%
wacmmse1=gmmseinvlong1(1,:);
wacmmse2=gmmseinvlong2(1,:);
%
% Channel 1 frequency response
%
Wacmmse1=wacmmse1*exp(-j*2*pi*linspace(0,K_b,K_b)'*freq);
figure(6)
plot(freq, 10*log10(abs(Wacmmse1)),freq, 10*log10(abs(Gf1)))
xlabel('Normalized Frequency, f')
ylabel('Transfer function ,dB')
legend('MMSE Equalizer 1','Channel 1')
%
% Channel 2 frequency response
%
Wacmmse2=wacmmse2*exp(-j*2*pi*linspace(0,K_b,K_b)'*freq);
figure(7)
plot(freq, 10*log10(abs(Wacmmse2)),freq, 10*log10(abs(Gf2)))
xlabel('Normalized Frequency, f')
ylabel('Transfer function ,dB')
legend('MMSE Equalizer 2','Channel 2')
